# generated by datamodel-codegen:
#   filename:  data/role/DataConsumer.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from typing import Any

from pydantic import BaseModel, Field


class Model(BaseModel):
    __root__: Any = Field(
        ...,
        description='Users with Data Consumer role use different data assets for their day to day work.',
    )
