# generated by datamodel-codegen:
#   filename:  schema/api/services/createStorageService.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra, Field

from ...type import basic, entityReference, storage


class CreateStorageServiceRequest(BaseModel):
    class Config:
        extra = Extra.forbid

    name: basic.EntityName = Field(
        ..., description='Name that identifies the this entity instance uniquely'
    )
    description: Optional[str] = Field(
        None, description='Description of Storage entity.'
    )
    serviceType: Optional[storage.StorageServiceType] = None
    owner: Optional[entityReference.EntityReference] = Field(
        None, description='Owner of this storage service.'
    )
