# generated by datamodel-codegen:
#   filename:  schema/api/catalogVersion.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra, Field

from ..type import basic


class CatalogVersion(BaseModel):
    class Config:
        extra = Extra.forbid

    version: Optional[str] = Field(None, description='Software version of the catalog')
    revision: Optional[str] = Field(
        None, description='Software revision of the catalog'
    )
    timestamp: Optional[basic.Timestamp] = Field(None, description='Build timestamp')
