# generated by datamodel-codegen:
#   filename:  schema/metadataIngestion/databaseServiceQueryUsagePipeline.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra, Field


class DatabaseServiceQueryUsagePipeline(BaseModel):
    class Config:
        extra = Extra.forbid

    queryLogDuration: Optional[int] = Field(
        '1',
        description='Configuration to tune how far we want to look back in query logs to process usage data.',
    )
    stageFileLocation: Optional[str] = Field(
        '/tmp/query_log',
        description='Temporary file name to store the query logs before processing. Absolute file path required.',
    )
    resultLimit: Optional[int] = Field(
        '100', description='Configuration to set the limit for query logs'
    )
