# generated by datamodel-codegen:
#   filename:  schema/tests/column/columnValuesLengthsToBeBetween.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra, Field


class ColumnValueLengthsToBeBetween(BaseModel):
    class Config:
        extra = Extra.forbid

    minLength: Optional[int] = Field(
        None,
        description='The {minLength} for the column length. If minLength is not included, maxLength is treated as upperBound and there will be no minimum number of rows',
    )
    maxLength: Optional[int] = Field(
        None,
        description='The {maxLength} for the column length. if maxLength is not included, minLength is treated as lowerBound and there will eb no maximum number of rows',
    )
