# generated by datamodel-codegen:
#   filename:  schema/api/feed/threadCount.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from typing import List

from pydantic import BaseModel, Extra, Field, conint

from ...type import basic


class EntityLinkThreadCount(BaseModel):
    class Config:
        extra = Extra.forbid

    count: conint(ge=0) = Field(
        ..., description='Count of threads for the given entity link.'
    )
    entityLink: basic.EntityLink


class CountOfThreadsRelatedToAnEntity(BaseModel):
    class Config:
        extra = Extra.forbid

    totalCount: conint(ge=0) = Field(..., description='Total count of all the threads.')
    counts: List[EntityLinkThreadCount] = Field(..., description='')
