# generated by datamodel-codegen:
#   filename:  schema/security/client/oktaSSOClientConfig.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from typing import List, Optional

from pydantic import BaseModel, Extra, Field


class OktaSSOClientConfig(BaseModel):
    class Config:
        extra = Extra.forbid

    clientId: str = Field(..., description='Okta Client ID.')
    orgURL: str = Field(..., description='Okta org url.')
    privateKey: str = Field(..., description='Okta Private Key.')
    email: str = Field(..., description='Okta Service account Email.')
    scopes: Optional[List[str]] = Field(None, description='Okta client scopes.')
