# generated by datamodel-codegen:
#   filename:  schema/tests/column/columnValuesToBeNotNull.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra


class ColumnValuesToBeNotNull(BaseModel):
    class Config:
        extra = Extra.forbid

    columnValuesToBeNotNull: Optional[bool] = True
