# generated by datamodel-codegen:
#   filename:  schema/entity/services/connections/metadata/metadataESConnection.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from enum import Enum
from typing import Optional

from pydantic import BaseModel, Extra, Field

from .. import connectionBasicType


class MetadataESType(Enum):
    MetadataES = 'MetadataES'


class MetadataESConnection(BaseModel):
    class Config:
        extra = Extra.forbid

    type: Optional[MetadataESType] = Field('MetadataES', description='Service Type')
    includeTopics: Optional[bool] = Field(
        'true', description='Include Topics for Indexing'
    )
    includeTables: Optional[bool] = Field(
        'true', description='Include Tables for Indexing'
    )
    includeDashboards: Optional[bool] = Field(
        'true', description='Include Dashboards for Indexing'
    )
    includePipelines: Optional[bool] = Field(
        'true', description='Include Pipelines for Indexing'
    )
    includeUsers: Optional[bool] = Field(
        'true', description='Include Users for Indexing'
    )
    includeTeams: Optional[bool] = Field(
        'true', description='Include Teams for Indexing'
    )
    includeGlossaryTerms: Optional[bool] = Field(
        'true', description='Include Glossary Terms for Indexing'
    )
    limitRecords: Optional[int] = Field(
        '1000', description='Limit the number of records for Indexing.'
    )
    supportsMetadataExtraction: Optional[
        connectionBasicType.SupportsMetadataExtraction
    ] = None
