# generated by datamodel-codegen:
#   filename:  schema/security/credentials/s3Credentials.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra, Field, SecretStr


class S3Credentials(BaseModel):
    class Config:
        extra = Extra.forbid

    awsAccessKeyId: str = Field(..., description='AWS Access key ID.')
    awsSecretAccessKey: SecretStr = Field(..., description='AWS Secret Access Key.')
    awsRegion: str = Field(..., description='AWS Region')
    awsSessionToken: Optional[str] = Field(None, description='AWS Session Token.')
    endPointURL: Optional[str] = Field(None, description='EndPoint URL for the AWS')
