# generated by datamodel-codegen:
#   filename:  schema/type/include.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from enum import Enum


class Include(Enum):
    all = 'all'
    deleted = 'deleted'
    non_deleted = 'non-deleted'
