# generated by datamodel-codegen:
#   filename:  schema/metadataIngestion/messagingServiceMetadataPipeline.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra, Field

from ..type import filterPattern


class MessagingServiceMetadataPipeline(BaseModel):
    class Config:
        extra = Extra.forbid

    topicFilterPattern: Optional[filterPattern.FilterPattern] = Field(
        None, description='Regex to only fetch topics that matches the pattern.'
    )
