# generated by datamodel-codegen:
#   filename:  schema/tests/column/columnValuesMissingCountToBeEqual.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from typing import List, Optional

from pydantic import BaseModel, Extra, Field


class ColumnValuesMissingCount(BaseModel):
    class Config:
        extra = Extra.forbid

    missingCountValue: Optional[int] = Field(
        None, description='No.of missing values to be equal to.'
    )
    missingValueMatch: Optional[List[str]] = Field(
        None,
        description='By default match all null and empty values to be missing. This field allows us to configure additional strings such as N/A, NULL as missing strings as well.',
    )
