"""
Provides metadata version information.
"""

# This file is auto-generated! Do not edit!
# Use `python -m incremental.update metadata` to change this file.

from incremental import Version

__version__ = Version("metadata", 0, 10, 0, dev=0)
__all__ = ["__version__"]
