# generated by datamodel-codegen:
#   filename:  schema/security/client/auth0SSOClientConfig.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from pydantic import BaseModel, Extra, Field


class Auth0SSOClientConfig(BaseModel):
    class Config:
        extra = Extra.forbid

    clientId: str = Field(..., description='Auth0 Client ID.')
    secretKey: str = Field(..., description='Auth0 Client Secret Key.')
    domain: str = Field(..., description='Auth0 Domain.')
